<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1">
<context>
    <name>AboutDialog</name>
    <message>
        <source>A simple, user-friendly Jabber/XMPP client</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>License:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>View source code online</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Report problems</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AccountSecurity</name>
    <message>
        <source>Account Security</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Allow to add new devices using a QR-Code, but never show the password as text. This action can not be undone, so consider storing the password in another way before using it.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disable showing the password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Don&apos;t expose the password in any form. This action can not be undone.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disable showing the QR-Code and password</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AccountTransferPage</name>
    <message>
        <source>Transfer account to another device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scan the QR code or enter the credentials as text on another device to log in on it.

Attention:
Never show this QR code to anyone else. It would allow unlimited access to your account!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Chat address:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide QR code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show as QR code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show as text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy JID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy password</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ChangePassword</name>
    <message>
        <source>Change password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Current password:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New password:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New password (repeat):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New passwords do not match.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Current password is invalid.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>After changing your password, you will need to reenter it on all your other devices.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Change</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password changed successfully</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to change password: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ChatMessage</name>
    <message>
        <source>Spoiler</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ChatMessageContextMenu</name>
    <message>
        <source>Copy message</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit message</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy download URL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Quote message</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ChatPage</name>
    <message>
        <source>Send a spoiler message</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unmute notifications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mute notifications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>View profile</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close message search bar</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ChatPageSendingPane</name>
    <message>
        <source>Spoiler hint</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close spoiler hint field</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Compose message</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ClientWorker</name>
    <message>
        <source>Your account could not be deleted from the server. Therefore, it was also not removed from this app: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CommonEncoderSettings</name>
    <message>
        <source>Very low</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Low</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Normal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>High</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Very high</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Constant quality</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Constant bit rate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Average bit rate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Two pass</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConfirmationPage</name>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConnectionSettings</name>
    <message>
        <source>Connection settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Change</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connection settings could not be changed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connection settings changed</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CustomConnectionSettings</name>
    <message>
        <source>Hostname:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The hostname must not contain blank spaces</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Port:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DisablePasswordDisplay</name>
    <message>
        <source>Remove password completely</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Your password will not be included in the QR code anymore.
You won&apos;t be able to use the login via QR code without entering your password again because this action cannot be undone!
Make sure that you backed it up if you want to use your account later.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove password</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DisablePlainTextPasswordDisplay</name>
    <message>
        <source>Do not show password as text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Your password will not be shown as text anymore.
You won&apos;t be able to see your password as text again because this action cannot be undone!
Make sure that you backed it up if you want to use your account later.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do not show password</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DownloadJob</name>
    <message>
        <source>Could not save file: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download failed: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EmptyChatPage</name>
    <message>
        <source>Please select a chat to start messaging</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GlobalDrawer</name>
    <message>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invite friends</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invitation link copied to clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Offline</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Online</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connecting…</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switch device</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Kaidan</name>
    <message>
        <source>The link will be opened after you have connected.</source>
        <extracomment>The link is an XMPP-URI (i.e. &apos;xmpp:kaidan@muc.kaidan.im?join&apos; for joining a chat)</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No valid login QR code found.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LocalAccountRemoval</name>
    <message>
        <source>Remove account from this app</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Your account will be removed from this app.
Your password will be deleted, make sure it is stored in a password manager or you know it!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LoginPage</name>
    <message>
        <source>Log in</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log in to your XMPP account</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connecting…</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connection settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LoginSettingsPage</name>
    <message>
        <source>Connection settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The connection settings will be saved permanently after the first successful login. If they don&apos;t work, you&apos;ll get back to the login page.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable custom connection settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Port:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hostname:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Apply</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MediaRecorder</name>
    <message>
        <source>Default</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MediaUtils</name>
    <message>
        <source>Take picture</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Record video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Record voice</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Send location</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose audio file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose document</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Images</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Documents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 (%2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Document</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Location</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Message</name>
    <message>
        <source>Spoiler</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MessageHandler</name>
    <message>
        <source>Message could not be sent.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Message correction was not successful.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MessageModel</name>
    <message>
        <source>Pending</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delivered</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MultimediaSettings</name>
    <message>
        <source>Multimedia Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Configure</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image Capture</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio Recording</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video Recording</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Camera</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio input</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Container</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Codec</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Quality</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sample Rate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Frame Rate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ready</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Initializing…</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unavailable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Recording…</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paused</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NewMedia</name>
    <message>
        <source>Initializing…</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unavailable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Recording… %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paused %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PasswordRemovalPage</name>
    <message>
        <source>Remove password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can decide to only not show your password for &lt;b&gt;%1&lt;/b&gt; as text anymore or to remove it completely from the account transfer. If you remove your password completely, you won&apos;t be able to use the account transfer via scanning without entering your password because it is also removed from the QR code.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do not show password as text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove completely</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Mark as read</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Free for chat</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Away</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do not disturb</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Away for longer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Offline</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QmlUtils</name>
    <message>
        <source>Invalid username or password.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot connect to the server. Please check your internet connection.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The server doesn&apos;t support secure connections.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error while trying to connect securely.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Authentification protocol not supported by the server.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This server does not support registration.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The server is offline or blocked by a firewall.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The connection could not be refreshed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The internet access is not permitted. Please check your system&apos;s internet access configuration.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Could not connect to the server. Please check your internet connection or your server name.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QrCodeGenerator</name>
    <message>
        <source>Generating the QR code failed: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QrCodeOnboardingPage</name>
    <message>
        <source>Scan QR code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show explanation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Continue without QR code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scan the QR code from your existing device to transfer your account.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connecting…</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QrCodeScanner</name>
    <message>
        <source>The camera format &apos;%1&apos; is not supported.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>There is no camera available.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Your camera is busy.
Try to close other applications using the camera.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RegistrationLoginDecisionPage</name>
    <message>
        <source>Set up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Register a new account</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use an existing account</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RemoteAccountDeletion</name>
    <message>
        <source>Delete account completely</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Your account will be deleted completely, which means from this app and from the server.
You will not be able to use your account again!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RosterAddContactSheet</name>
    <message>
        <source>Add new contact</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This will also send a request to access the presence of the contact.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Jabber-ID:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>user@example.org</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Nickname:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Optional message:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tell your chat partner who you are.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RosterManager</name>
    <message>
        <source>Could not add contact, as a result of not being connected.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Could not remove contact, as a result of not being connected.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Could not rename contact, as a result of not being connected.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RosterPage</name>
    <message>
        <source>Connecting…</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Contacts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add new contact</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Offline</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search contacts</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RosterRemoveContactSheet</name>
    <message>
        <source>Delete contact</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do you really want to delete the contact &lt;b&gt;%1&lt;/b&gt; from your contact list?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RosterRenameContactSheet</name>
    <message>
        <source>Rename contact</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SendMediaSheet</name>
    <message>
        <source>Caption</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Send</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ServerListModel</name>
    <message>
        <source>Custom server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No limitation</source>
        <extracomment>Unlimited file size for uploading files
----------
Deletion of message history saved on server</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 days</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsContent</name>
    <message>
        <source>Change password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Changes your account&apos;s password. You will need to re-enter it on your other devices.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Multimedia Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Configure photo, video and audio recording settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Account security</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove account from Kaidan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove account from this app</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete account</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete account from the server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connection Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Configure the hostname and port to connect to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Configure whether this device can be used to log in on a new device</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsPage</name>
    <message>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StartPage</name>
    <message>
        <source>Enjoy free communication on every device!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Let&apos;s start</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SubRequestAcceptSheet</name>
    <message>
        <source>Subscription Request</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You received a subscription request by &lt;b&gt;%1&lt;/b&gt;. If you accept it, the account will have access to your presence status.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Decline</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Accept</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UploadManager</name>
    <message>
        <source>Could not send file, as a result of not being connected.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Message could not be sent.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UserProfilePage</name>
    <message>
        <source>Profile</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename contact</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show QR code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove contact</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Online devices</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>VCardModel</name>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Email</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Birthday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Website</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
